=== modified file 'drizzled/sql_class.cc'
--- drizzled/sql_class.cc	2008-11-04 00:22:10 +0000
+++ drizzled/sql_class.cc	2008-11-11 04:33:12 +0000
@@ -2619,7 +2619,7 @@
 int Session::binlog_write_row(Table* table, bool is_trans, 
                           unsigned char const *record) 
 { 
-  assert(current_stmt_binlog_row_based && mysql_bin_log.is_open());
+  assert(mysql_bin_log.is_open());
 
   /*
     Pack records into format for transfer. We are allocating more
@@ -2647,7 +2647,7 @@
                            const unsigned char *before_record,
                            const unsigned char *after_record)
 { 
-  assert(current_stmt_binlog_row_based && mysql_bin_log.is_open());
+  assert(mysql_bin_log.is_open());
 
   size_t const before_maxlen = table->max_row_length(before_record);
   size_t const after_maxlen  = table->max_row_length(after_record);
@@ -2680,7 +2680,7 @@
 int Session::binlog_delete_row(Table* table, bool is_trans, 
                            unsigned char const *record)
 { 
-  assert(current_stmt_binlog_row_based && mysql_bin_log.is_open());
+  assert(mysql_bin_log.is_open());
 
   /* 
      Pack records into format for transfer. We are allocating more
@@ -2791,9 +2791,7 @@
 
   switch (qtype) {
   case Session::ROW_QUERY_TYPE:
-    if (current_stmt_binlog_row_based)
-      return(0);
-    /* Otherwise, we fall through */
+    return(0);
   case Session::DRIZZLE_QUERY_TYPE:
     /*
       Using this query type is a conveniece hack, since we have been

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2008-11-11 02:57:53 +0000
+++ drizzled/sql_delete.cc	2008-11-11 04:33:12 +0000
@@ -121,9 +121,7 @@
       - We should not be binlogging this statement row-based, and
       - there should be no delete triggers associated with the table.
   */
-  if (!using_limit && const_cond_result &&
-      (session->lex->sql_command == SQLCOM_TRUNCATE ||
-       (!session->current_stmt_binlog_row_based)))
+  if (!using_limit && const_cond_result)
   {
     /* Update the table->file->stats.records number */
     table->file->info(HA_STATUS_VARIABLE | HA_STATUS_NO_LOCK);
@@ -927,8 +925,6 @@
   session->options&= ~(OPTION_BEGIN | OPTION_NOT_AUTOCOMMIT);
   ha_enable_transaction(session, false);
   mysql_init_select(session->lex);
-  bool save_binlog_row_based= session->current_stmt_binlog_row_based;
-  session->clear_current_stmt_binlog_row_based();
   error= mysql_delete(session, table_list, (COND*) 0, (SQL_LIST*) 0,
                       HA_POS_ERROR, 0L, true);
   ha_enable_transaction(session, true);
@@ -939,6 +935,5 @@
   error= ha_autocommit_or_rollback(session, error);
   ha_commit(session);
   session->options= save_options;
-  session->current_stmt_binlog_row_based= save_binlog_row_based;
   return(error);
 }

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2008-11-04 00:22:10 +0000
+++ drizzled/sql_load.cc	2008-11-11 04:33:12 +0000
@@ -438,32 +438,7 @@
     session->transaction.all.modified_non_trans_table= true;
 
   if (mysql_bin_log.is_open())
-  {
-    /*
-      We need to do the job that is normally done inside
-      binlog_query() here, which is to ensure that the pending event
-      is written before tables are unlocked and before any other
-      events are written.  We also need to update the table map
-      version for the binary log to mark that table maps are invalid
-      after this point.
-     */
-    if (session->current_stmt_binlog_row_based)
-      session->binlog_flush_pending_rows_event(true);
-    else
-    {
-      /*
-        As already explained above, we need to call end_io_cache() or the last
-        block will be logged only after Execute_load_query_log_event (which is
-        wrong), when read_info is destroyed.
-      */
-      read_info.end_io_cache();
-      if (lf_info.wrote_create_file)
-      {
-        write_execute_load_query_log_event(session, handle_duplicates, ignore,
-                                           transactional_table,killed_status);
-      }
-    }
-  }
+    session->binlog_flush_pending_rows_event(true);
 
   /* ok to client sent only after binlog write and engine commit */
   my_ok(session, info.copied + info.deleted, 0L, name);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2008-11-04 00:22:10 +0000
+++ drizzled/sql_table.cc	2008-11-11 04:33:12 +0000
@@ -355,7 +355,7 @@
   bool some_tables_deleted=0, tmp_table_deleted=0, foreign_key_error=0;
   String built_query;
 
-  if (session->current_stmt_binlog_row_based && !dont_log_query)
+  if (!dont_log_query)
   {
     built_query.set_charset(system_charset_info);
     if (if_exists)
@@ -419,7 +419,7 @@
       being built.  The string always end in a comma and the comma
       will be chopped off before being written to the binary log.
       */
-    if (session->current_stmt_binlog_row_based && !dont_log_query)
+    if (!dont_log_query)
     {
       non_temp_tables_count++;
       /*
@@ -541,8 +541,7 @@
   {
     if (!dont_log_query)
     {
-      if (!session->current_stmt_binlog_row_based ||
-          (non_temp_tables_count > 0 && !tmp_table_deleted))
+      if ((non_temp_tables_count > 0 && !tmp_table_deleted))
       {
         /*
           In this case, we are either using statement-based
@@ -553,8 +552,7 @@
          */
         write_bin_log(session, !error, session->query, session->query_length);
       }
-      else if (session->current_stmt_binlog_row_based &&
-               non_temp_tables_count > 0 &&
+      else if (non_temp_tables_count > 0 &&
                tmp_table_deleted)
       {
         /*
@@ -1898,9 +1896,7 @@
     Otherwise, the statement shall be binlogged.
    */
   if (!internal_tmp_table &&
-      (!session->current_stmt_binlog_row_based ||
-       (session->current_stmt_binlog_row_based &&
-        !(create_info->options & HA_LEX_CREATE_TMP_TABLE))))
+      ((!(create_info->options & HA_LEX_CREATE_TMP_TABLE))))
     write_bin_log(session, true, session->query, session->query_length);
   error= false;
 unlock_and_end:
@@ -3023,7 +3019,6 @@
   /*
     We have to write the query before we unlock the tables.
   */
-  if (session->current_stmt_binlog_row_based)
   {
     /*
        Since temporary tables are not replicated under row-based
@@ -3077,8 +3072,6 @@
       Case 3 and 4 does nothing under RBR
     */
   }
-  else
-    write_bin_log(session, true, session->query, session->query_length);
 
   res= false;
   goto err;
@@ -4885,9 +4878,6 @@
     /* Should pass the 'new_name' as we store table name in the cache */
     if (rename_temporary_table(session, new_table, new_db, new_name))
       goto err1;
-    /* We don't replicate alter table statement on temporary tables */
-    if (!session->current_stmt_binlog_row_based)
-      write_bin_log(session, true, session->query, session->query_length);
     goto end_temporary;
   }
 
@@ -4988,7 +4978,6 @@
   session->set_proc_info("end");
 
   assert(!(mysql_bin_log.is_open() &&
-                session->current_stmt_binlog_row_based &&
                 (create_info->options & HA_LEX_CREATE_TMP_TABLE)));
   write_bin_log(session, true, session->query, session->query_length);
 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2008-11-07 06:31:49 +0000
+++ drizzled/table.cc	2008-11-11 04:33:12 +0000
@@ -3195,8 +3195,7 @@
     }
     file->column_bitmaps_signal();
   }
-  if (file->ha_table_flags() & HA_PRIMARY_KEY_REQUIRED_FOR_DELETE ||
-      (mysql_bin_log.is_open() && in_use && in_use->current_stmt_binlog_row_based))
+  if (file->ha_table_flags() & HA_PRIMARY_KEY_REQUIRED_FOR_DELETE || (mysql_bin_log.is_open() && in_use))
   {
     /*
       If the handler has no cursor capabilites, or we have row-based
@@ -3248,7 +3247,7 @@
     file->column_bitmaps_signal();
   }
   if ((file->ha_table_flags() & HA_PRIMARY_KEY_REQUIRED_FOR_DELETE) ||
-      (mysql_bin_log.is_open() && in_use && in_use->current_stmt_binlog_row_based))
+      (mysql_bin_log.is_open() && in_use))
   {
     /*
       If the handler has no cursor capabilites, or we have row-based

